@@ -32,7 +32,7 @@
 #define ENTERING qWarning() << "[" << __PRETTY_FUNCTION__ << "] <<Entering>>"
 #define LEAVING qWarning() << "[" << __PRETTY_FUNCTION__ << "] <<Leaving>>"
 #define TRACE qWarning() << "[" << __PRETTY_FUNCTION__ << "]"
-#define TSHOW(V) qWarning() << "[" << __PRETTY_FUNCTION__ << "]" << #V << "=" << (V)
+#define TSHOW(V) qWarning() << "[" << __PRETTY_FUNCTION__ << __LINE__ << "]" << #V << "=" << (V)
 #define SHOW(V) qWarning() << #V << "=" << (V)
 #else
 #define ENTERING while (false)
@@ -51,14 +51,11 @@
 template <typename T> inline void unused(const T &, ...) {}
 
 #ifdef _TIMING_ENABLED_
-#define TIMING TimeLogger::getInstance()->step(__PRETTY_FUNCTION__, __LINE__, __FILE__);
+#define TIMING TimeLogger::getInstance()->step(__PRETTY_FUNCTION__, __LINE__, __FILE__)
 #else
 #define TIMING                                                                                                                                                                                         \
   if (false)                                                                                                                                                                                           \
   std::cout << ""
-#define TIMING_CLOSE                                                                                                                                                                                   \
-  if (false)                                                                                                                                                                                           \
-  std::cout << ""
 #endif
 
 #endif // _GMIC_QT_COMMON_H
