@@ -33,7 +33,7 @@
 #include "DialogSettings.h"
 #include "HtmlTranslator.h"
 
-BoolParameter::BoolParameter(QObject * parent) : AbstractParameter(parent, true), _default(false), _value(false), _label(0), _checkBox(0), _connected(false) {}
+BoolParameter::BoolParameter(QObject * parent) : AbstractParameter(parent, true), _default(false), _value(false), _label(nullptr), _checkBox(nullptr), _connected(false) {}
 
 BoolParameter::~BoolParameter()
 {
@@ -41,11 +41,11 @@ BoolParameter::~BoolParameter()
   delete _label;
 }
 
-void BoolParameter::addTo(QWidget * widget, int row)
+bool BoolParameter::addTo(QWidget * widget, int row)
 {
-  QGridLayout * grid = dynamic_cast<QGridLayout *>(widget->layout());
-  if (!grid)
-    return;
+  _grid = dynamic_cast<QGridLayout *>(widget->layout());
+  Q_ASSERT_X(_grid, __PRETTY_FUNCTION__, "No grid layout in widget");
+  _row = row;
   delete _checkBox;
   delete _label;
   _checkBox = new QCheckBox(_name, widget);
@@ -56,13 +56,14 @@ void BoolParameter::addTo(QWidget * widget, int row)
     p.setColor(QPalette::Base, DialogSettings::CheckBoxBaseColor);
     _checkBox->setPalette(p);
   }
-  grid->addWidget(_checkBox, row, 0, 1, 3);
+  _grid->addWidget(_checkBox, row, 0, 1, 3);
   connectCheckBox();
+  return true;
 }
 
 QString BoolParameter::textValue() const
 {
-  return _value ? "1" : "0";
+  return _value ? QString("1") : QString("0");
 }
 
 void BoolParameter::setValue(const QString & value)
