@@ -31,23 +31,24 @@
 #include "Common.h"
 #include "HtmlTranslator.h"
 
-ButtonParameter::ButtonParameter(QObject * parent) : AbstractParameter(parent, true), _value(false), _pushButton(0), _alignment(Qt::AlignHCenter) {}
+ButtonParameter::ButtonParameter(QObject * parent) : AbstractParameter(parent, true), _value(false), _pushButton(nullptr), _alignment(Qt::AlignHCenter) {}
 
 ButtonParameter::~ButtonParameter()
 {
   delete _pushButton;
 }
 
-void ButtonParameter::addTo(QWidget * widget, int row)
+bool ButtonParameter::addTo(QWidget * widget, int row)
 {
-  QGridLayout * grid = dynamic_cast<QGridLayout *>(widget->layout());
-  if (!grid)
-    return;
+  _grid = dynamic_cast<QGridLayout *>(widget->layout());
+  Q_ASSERT_X(_grid, __PRETTY_FUNCTION__, "No grid layout in widget");
+  _row = row;
   delete _pushButton;
   _pushButton = new QPushButton(_text, widget);
   _pushButton->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
-  grid->addWidget(_pushButton, row, 0, 1, 3, _alignment);
+  _grid->addWidget(_pushButton, row, 0, 1, 3, _alignment);
   connect(_pushButton, SIGNAL(clicked(bool)), this, SLOT(onPushButtonClicked(bool)));
+  return true;
 }
 
 QString ButtonParameter::textValue() const
@@ -80,15 +81,14 @@ bool ButtonParameter::initFromText(const char * text, int & textLength)
   QString & alignment = list[1];
   if (alignment.isEmpty()) {
     return true;
+  }
+  float a = alignment.toFloat();
+  if (a == 0.0f) {
+    _alignment = Qt::AlignLeft;
+  } else if (a == 1.0f) {
+    _alignment = Qt::AlignRight;
   } else {
-    float a = alignment.toFloat();
-    if (a == 0.0f) {
-      _alignment = Qt::AlignLeft;
-    } else if (a == 1.0f) {
-      _alignment = Qt::AlignRight;
-    } else {
-      _alignment = Qt::AlignCenter;
-    }
+    _alignment = Qt::AlignCenter;
   }
   return true;
 }
