@@ -38,7 +38,7 @@
 #include "DialogSettings.h"
 #include "HtmlTranslator.h"
 
-ColorParameter::ColorParameter(QObject * parent) : AbstractParameter(parent, true), _default(0, 0, 0, 0), _value(_default), _alphaChannel(false), _label(0), _button(0), _dialog(0) {}
+ColorParameter::ColorParameter(QObject * parent) : AbstractParameter(parent, true), _default(0, 0, 0, 0), _value(_default), _alphaChannel(false), _label(nullptr), _button(nullptr), _dialog(nullptr) {}
 
 ColorParameter::~ColorParameter()
 {
@@ -47,11 +47,11 @@ ColorParameter::~ColorParameter()
   delete _dialog;
 }
 
-void ColorParameter::addTo(QWidget * widget, int row)
+bool ColorParameter::addTo(QWidget * widget, int row)
 {
-  QGridLayout * grid = dynamic_cast<QGridLayout *>(widget->layout());
-  if (!grid)
-    return;
+  _grid = dynamic_cast<QGridLayout *>(widget->layout());
+  Q_ASSERT_X(_grid, __PRETTY_FUNCTION__, "No grid layout in widget");
+  _row = row;
   delete _button;
   delete _label;
 
@@ -67,9 +67,10 @@ void ColorParameter::addTo(QWidget * widget, int row)
 
   updateButtonColor();
 
-  grid->addWidget(_label = new QLabel(_name, widget), row, 0, 1, 1);
-  grid->addWidget(_button, row, 1, 1, 1);
+  _grid->addWidget(_label = new QLabel(_name, widget), row, 0, 1, 1);
+  _grid->addWidget(_button, row, 1, 1, 1);
   connect(_button, SIGNAL(clicked()), this, SLOT(onButtonPressed()));
+  return true;
 }
 
 QString ColorParameter::textValue() const
@@ -77,9 +78,8 @@ QString ColorParameter::textValue() const
   const QColor & c = _value;
   if (_alphaChannel) {
     return QString("%1,%2,%3,%4").arg(c.red()).arg(c.green()).arg(c.blue()).arg(c.alpha());
-  } else {
-    return QString("%1,%2,%3").arg(c.red()).arg(c.green()).arg(c.blue());
   }
+  return QString("%1,%2,%3").arg(c.red()).arg(c.green()).arg(c.blue());
 }
 
 void ColorParameter::setValue(const QString & value)
@@ -113,8 +113,8 @@ bool ColorParameter::initFromText(const char * text, int & textLength)
   const int n = channels.size();
   bool okR = true, okG = true, okB = true, okA = true;
   int r = (n > 0) ? channels[0].toInt(&okR) : 0;
-  int g = (n >= 2) ? channels[1].toInt(&okG) : 0;
-  int b = (n >= 3) ? channels[2].toInt(&okB) : 0;
+  int g = (n >= 2) ? channels[1].toInt(&okG) : r;
+  int b = (n >= 3) ? channels[2].toInt(&okB) : (n == 1) ? r : 0;
   if (channels.size() == 4) {
     int a = channels[3].toInt(&okA);
     _default = _value = QColor(r, g, b, a);
