@@ -30,15 +30,13 @@
 
 ConstParameter::ConstParameter(QObject * parent) : AbstractParameter(parent, true) {}
 
-ConstParameter::~ConstParameter() {}
+ConstParameter::~ConstParameter() = default;
 
-bool ConstParameter::isVisible() const
+bool ConstParameter::addTo(QWidget *, int)
 {
   return false;
 }
 
-void ConstParameter::addTo(QWidget *, int) {}
-
 QString ConstParameter::textValue() const
 {
   return _value;
