@@ -37,7 +37,7 @@
 #include "HtmlTranslator.h"
 #include "IconLoader.h"
 
-FileParameter::FileParameter(QObject * parent) : AbstractParameter(parent, true), _label(0), _button(0), _dialogMode(InputOutputMode) {}
+FileParameter::FileParameter(QObject * parent) : AbstractParameter(parent, true), _label(nullptr), _button(nullptr), _dialogMode(InputOutputMode) {}
 
 FileParameter::~FileParameter()
 {
@@ -45,11 +45,11 @@ FileParameter::~FileParameter()
   delete _button;
 }
 
-void FileParameter::addTo(QWidget * widget, int row)
+bool FileParameter::addTo(QWidget * widget, int row)
 {
-  QGridLayout * grid = dynamic_cast<QGridLayout *>(widget->layout());
-  if (!grid)
-    return;
+  _grid = dynamic_cast<QGridLayout *>(widget->layout());
+  Q_ASSERT_X(_grid, __PRETTY_FUNCTION__, "No grid layout in widget");
+  _row = row;
   delete _label;
   delete _button;
 
@@ -63,9 +63,10 @@ void FileParameter::addTo(QWidget * widget, int row)
   }
   _button = new QPushButton(buttonText, widget);
   _button->setIcon(LOAD_ICON("document-open"));
-  grid->addWidget(_label = new QLabel(_name, widget), row, 0, 1, 1);
-  grid->addWidget(_button, row, 1, 1, 2);
+  _grid->addWidget(_label = new QLabel(_name, widget), row, 0, 1, 1);
+  _grid->addWidget(_button, row, 1, 1, 2);
   connect(_button, SIGNAL(clicked()), this, SLOT(onButtonPressed()));
+  return true;
 }
 
 QString FileParameter::textValue() const
@@ -147,7 +148,7 @@ void FileParameter::onButtonPressed()
     filename = QFileDialog::getSaveFileName(QApplication::topLevelWidgets().at(0), tr("Select a file"), folder, QString(), nullptr);
     break;
   case InputOutputMode: {
-    QFileDialog dialog(0, tr("Select a file"), folder, QString());
+    QFileDialog dialog(dynamic_cast<QWidget *>(parent()), tr("Select a file"), folder, QString());
     dialog.setOptions(QFileDialog::DontConfirmOverwrite | QFileDialog::DontUseNativeDialog);
     dialog.setFileMode(QFileDialog::AnyFile);
     if (!_value.isEmpty()) {
