@@ -48,6 +48,7 @@ bool FilterParametersWidget::build(const QString & name, const QString & hash, c
 {
   _filterName = name;
   _filterHash = hash;
+  hide();
   clear();
   delete layout();
   auto grid = new QGridLayout(this);
@@ -103,9 +104,9 @@ bool FilterParametersWidget::build(const QString & name, const QString & hash, c
   QVector<AbstractParameter *>::iterator it = _presetParameters.begin();
   while (it != _presetParameters.end()) {
     AbstractParameter * parameter = *it;
-    if (parameter->isVisible()) {
-      parameter->addTo(this, row++);
-      grid->setRowStretch(row - 1, 0);
+    if (parameter->addTo(this, row)) {
+      grid->setRowStretch(row, 0);
+      ++row;
     }
     connect(parameter, SIGNAL(valueChanged()), this, SLOT(updateValueString()));
     ++it;
@@ -156,6 +157,7 @@ bool FilterParametersWidget::build(const QString & name, const QString & hash, c
     grid->addWidget(_labelNoParams, 0, 0, 4, 3);
   }
   updateValueString(false);
+  show();
   return error.isEmpty();
 }
 
@@ -217,7 +219,7 @@ void FilterParametersWidget::setValues(const QStringList & list, bool notify)
   updateValueString(notify);
 }
 
-void FilterParametersWidget::setVisibilityStates(const QList<int> states)
+void FilterParametersWidget::setVisibilityStates(const QList<int> & states)
 {
   if (states.isEmpty()) {
     return;
@@ -234,11 +236,7 @@ void FilterParametersWidget::setVisibilityStates(const QList<int> states)
     for (int n = 0; n < _presetParameters.size(); ++n) {
       AbstractParameter * parameter = _presetParameters[n];
       if (parameter->isActualParameter()) {
-        if (parameter->isVisible()) {
-          newVisibilityStates[n] = static_cast<AbstractParameter::VisibilityState>(*itState);
-        } else {
-          newVisibilityStates[n] = parameter->defaultVisibilityState();
-        }
+        newVisibilityStates[n] = static_cast<AbstractParameter::VisibilityState>(*itState);
         ++itState;
       }
     }
@@ -246,7 +244,7 @@ void FilterParametersWidget::setVisibilityStates(const QList<int> states)
   // Propagate if necessary
   for (int n = 0; n < _presetParameters.size(); ++n) {
     AbstractParameter * parameter = _presetParameters[n];
-    if (parameter->isActualParameter() && parameter->isVisible()) {
+    if (parameter->isActualParameter()) {
       AbstractParameter::VisibilityState state = newVisibilityStates[n];
       if (state == AbstractParameter::UnspecifiedVisibilityState) {
         state = parameter->defaultVisibilityState();
@@ -268,16 +266,14 @@ void FilterParametersWidget::setVisibilityStates(const QList<int> states)
 
   for (int n = 0; n < _presetParameters.size(); ++n) {
     AbstractParameter * const parameter = _presetParameters[n];
-    if (parameter->isVisible()) {
-      parameter->setVisibilityState(newVisibilityStates[n]);
-    }
+    parameter->setVisibilityState(newVisibilityStates[n]);
   }
 }
 
 QList<int> FilterParametersWidget::visibilityStates()
 {
   QList<int> states;
-  for (AbstractParameter * param : _presetParameters) {
+  for (const AbstractParameter * const param : _presetParameters) {
     if (param->isActualParameter()) {
       states.push_back(param->visibilityState());
     }
