@@ -34,7 +34,7 @@
 #include "Globals.h"
 #include "HtmlTranslator.h"
 
-IntParameter::IntParameter(QObject * parent) : AbstractParameter(parent, true), _min(0), _max(0), _default(0), _value(0), _label(0), _slider(0), _spinBox(0)
+IntParameter::IntParameter(QObject * parent) : AbstractParameter(parent, true), _min(0), _max(0), _default(0), _value(0), _label(nullptr), _slider(nullptr), _spinBox(nullptr)
 {
   _timerId = 0;
   _connected = false;
@@ -47,11 +47,11 @@ IntParameter::~IntParameter()
   delete _label;
 }
 
-void IntParameter::addTo(QWidget * widget, int row)
+bool IntParameter::addTo(QWidget * widget, int row)
 {
-  QGridLayout * grid = dynamic_cast<QGridLayout *>(widget->layout());
-  if (!grid)
-    return;
+  _grid = dynamic_cast<QGridLayout *>(widget->layout());
+  Q_ASSERT_X(_grid, __PRETTY_FUNCTION__, "No grid layout in widget");
+  _row = row;
   delete _spinBox;
   delete _slider;
   delete _label;
@@ -68,16 +68,13 @@ void IntParameter::addTo(QWidget * widget, int row)
     p.setColor(QPalette::Highlight, QColor(130, 130, 130));
     _slider->setPalette(p);
   }
-  grid->addWidget(_label = new QLabel(_name, widget), row, 0, 1, 1);
-  grid->addWidget(_slider, row, 1, 1, 1);
-  grid->addWidget(_spinBox, row, 2, 1, 1);
+  _grid->addWidget(_label = new QLabel(_name, widget), row, 0, 1, 1);
+  _grid->addWidget(_slider, row, 1, 1, 1);
+  _grid->addWidget(_spinBox, row, 2, 1, 1);
   connectSliderSpinBox();
+  return true;
 }
 
-void IntParameter::addToKeypointList(KeypointList &) const {}
-
-void IntParameter::extractPositionFromKeypointList(KeypointList &) {}
-
 QString IntParameter::textValue() const
 {
   return _spinBox->text();
