@@ -32,25 +32,26 @@
 #include "Common.h"
 #include "HtmlTranslator.h"
 
-LinkParameter::LinkParameter(QObject * parent) : AbstractParameter(parent, false), _label(0), _alignment(Qt::AlignLeft) {}
+LinkParameter::LinkParameter(QObject * parent) : AbstractParameter(parent, false), _label(nullptr), _alignment(Qt::AlignLeft) {}
 
 LinkParameter::~LinkParameter()
 {
   delete _label;
 }
 
-void LinkParameter::addTo(QWidget * widget, int row)
+bool LinkParameter::addTo(QWidget * widget, int row)
 {
-  QGridLayout * grid = dynamic_cast<QGridLayout *>(widget->layout());
-  if (!grid)
-    return;
+  _grid = dynamic_cast<QGridLayout *>(widget->layout());
+  Q_ASSERT_X(_grid, __PRETTY_FUNCTION__, "No grid layout in widget");
+  _row = row;
   delete _label;
   _label = new QLabel(QString("<a href=\"%2\">%1</a>").arg(_text).arg(_url), widget);
   _label->setAlignment(_alignment);
   _label->setTextFormat(Qt::RichText);
   _label->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
   connect(_label, SIGNAL(linkActivated(QString)), this, SLOT(onLinkActivated(QString)));
-  grid->addWidget(_label, row, 0, 1, 3);
+  _grid->addWidget(_label, row, 0, 1, 3);
+  return true;
 }
 
 QString LinkParameter::textValue() const
@@ -93,7 +94,7 @@ bool LinkParameter::initFromText(const char * text, int & textLength)
   if (values.size() == 1) {
     _url = values[0].trimmed().remove(QRegExp("^\"")).remove(QRegExp("\"$"));
   }
-  if (!values.size()) {
+  if (values.isEmpty()) {
     return false;
   }
   if (_text.isEmpty()) {
