@@ -32,31 +32,28 @@
 #include "DialogSettings.h"
 #include "HtmlTranslator.h"
 
-NoteParameter::NoteParameter(QObject * parent) : AbstractParameter(parent, false), _label(0) {}
+NoteParameter::NoteParameter(QObject * parent) : AbstractParameter(parent, false), _label(nullptr) {}
 
 NoteParameter::~NoteParameter()
 {
   delete _label;
 }
 
-void NoteParameter::addTo(QWidget * widget, int row)
+bool NoteParameter::addTo(QWidget * widget, int row)
 {
-  QGridLayout * grid = dynamic_cast<QGridLayout *>(widget->layout());
-  if (!grid)
-    return;
+  _grid = dynamic_cast<QGridLayout *>(widget->layout());
+  Q_ASSERT_X(_grid, __PRETTY_FUNCTION__, "No grid layout in widget");
+  _row = row;
   delete _label;
   _label = new QLabel(_text, widget);
   _label->setTextFormat(Qt::RichText);
   _label->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
   _label->setWordWrap(true);
   connect(_label, SIGNAL(linkActivated(QString)), this, SLOT(onLinkActivated(QString)));
-  grid->addWidget(_label, row, 0, 1, 3);
+  _grid->addWidget(_label, row, 0, 1, 3);
+  return true;
 }
 
-void NoteParameter::addToKeypointList(KeypointList &) const {}
-
-void NoteParameter::extractPositionFromKeypointList(KeypointList &) {}
-
 QString NoteParameter::textValue() const
 {
   return QString::null;
