@@ -31,11 +31,9 @@ class QFrame;
 class SeparatorParameter : public AbstractParameter {
   Q_OBJECT
 public:
-  SeparatorParameter(QObject * parent = 0);
+  SeparatorParameter(QObject * parent = nullptr);
   ~SeparatorParameter();
-  void addTo(QWidget *, int row) override;
-  void addToKeypointList(KeypointList &) const override;
-  void extractPositionFromKeypointList(KeypointList &) override;
+  bool addTo(QWidget *, int row) override;
   QString textValue() const override;
   void setValue(const QString & value) override;
   void reset() override;
