@@ -35,10 +35,11 @@
 #include "DialogSettings.h"
 #include "FilterParameters/MultilineTextParameterWidget.h"
 #include "HtmlTranslator.h"
+#include "IconLoader.h"
 
-TextParameter::TextParameter(QObject * parent) : AbstractParameter(parent, true), _label(0), _lineEdit(0), _textEdit(0), _multiline(false), _connected(false)
+TextParameter::TextParameter(QObject * parent) : AbstractParameter(parent, true), _label(nullptr), _lineEdit(nullptr), _textEdit(nullptr), _multiline(false), _connected(false)
 {
-  _updateAction = 0;
+  _updateAction = nullptr;
 }
 
 TextParameter::~TextParameter()
@@ -48,29 +49,30 @@ TextParameter::~TextParameter()
   delete _label;
 }
 
-void TextParameter::addTo(QWidget * widget, int row)
+bool TextParameter::addTo(QWidget * widget, int row)
 {
-  QGridLayout * grid = dynamic_cast<QGridLayout *>(widget->layout());
-  if (!grid)
-    return;
+  _grid = dynamic_cast<QGridLayout *>(widget->layout());
+  Q_ASSERT_X(_grid, __PRETTY_FUNCTION__, "No grid layout in widget");
+  _row = row;
   delete _label;
   delete _lineEdit;
   delete _textEdit;
   if (_multiline) {
-    _label = 0;
-    _lineEdit = 0;
+    _label = nullptr;
+    _lineEdit = nullptr;
     _textEdit = new MultilineTextParameterWidget(_name, _value, widget);
-    grid->addWidget(_textEdit, row, 0, 1, 3);
+    _grid->addWidget(_textEdit, row, 0, 1, 3);
   } else {
-    grid->addWidget(_label = new QLabel(_name, widget), row, 0, 1, 1);
+    _grid->addWidget(_label = new QLabel(_name, widget), row, 0, 1, 1);
     _lineEdit = new QLineEdit(_value, widget);
-    _textEdit = 0;
-    grid->addWidget(_lineEdit, row, 1, 1, 2);
+    _textEdit = nullptr;
+    _grid->addWidget(_lineEdit, row, 1, 1, 2);
 #if QT_VERSION >= 0x050200
     _updateAction = _lineEdit->addAction(LOAD_ICON("view-refresh"), QLineEdit::TrailingPosition);
 #endif
   }
   connectEditor();
+  return true;
 }
 
 QString TextParameter::textValue() const
