@@ -39,7 +39,7 @@
 
 FiltersPresenter::FiltersPresenter(QObject * parent) : QObject(parent)
 {
-  _filtersView = 0;
+  _filtersView = nullptr;
 }
 
 FiltersPresenter::~FiltersPresenter()
@@ -64,7 +64,7 @@ void FiltersPresenter::rebuildFilterView()
   rebuildFilterViewWithSelection(QList<QString>());
 }
 
-void FiltersPresenter::rebuildFilterViewWithSelection(QList<QString> keywords)
+void FiltersPresenter::rebuildFilterViewWithSelection(const QList<QString> & keywords)
 {
   _filtersView->clear();
   _filtersView->disableModel();
@@ -109,25 +109,26 @@ void FiltersPresenter::readFaves()
   favesModelReader.loadFaves();
 }
 
-void FiltersPresenter::restoreFaveHashLinksRelease236()
+bool FiltersPresenter::allFavesAreValid() const
 {
-  if (QSettings().value("Faves/RelinkedFrom236", false).toBool()) {
-    return;
+  for (const FavesModel::Fave & fave : _favesModel) {
+    if (!_filtersModel.contains(fave.originalHash())) {
+      return false;
+    }
   }
-  unsigned int unknownFaveCount = 0;
-  FavesModel::const_iterator itFave = _favesModel.cbegin();
-  while (itFave != _favesModel.cend()) {
-    unknownFaveCount += !(_filtersModel.contains(itFave->originalHash()));
-    ++itFave;
-  }
-  if (!unknownFaveCount) {
+  return true;
+}
+
+void FiltersPresenter::restoreFaveHashLinksAfterCaseChange()
+{
+  if (allFavesAreValid()) {
     return;
   }
   FavesModel formerFaveModel = _favesModel;
-  itFave = formerFaveModel.cbegin();
+  FavesModel::const_iterator itFormerFave = formerFaveModel.cbegin();
   bool someFavesHaveBeenRelinked = false;
-  while (itFave != formerFaveModel.cend()) {
-    const FavesModel::Fave & fave = *itFave;
+  while (itFormerFave != formerFaveModel.cend()) {
+    const FavesModel::Fave & fave = *itFormerFave;
     if (!_filtersModel.contains(fave.originalHash())) {
       FiltersModel::const_iterator itFilter = _filtersModel.cbegin();
       while ((itFilter != _filtersModel.cend()) && (itFilter->hash236() != fave.originalHash())) {
@@ -147,12 +148,10 @@ void FiltersPresenter::restoreFaveHashLinksRelease236()
         Logger::log(message);
       }
     }
-    ++itFave;
+    ++itFormerFave;
   }
-
   if (someFavesHaveBeenRelinked) {
     saveFaves();
-    QSettings().setValue("Faves/RelinkedFrom236", true);
   }
 }
 
@@ -168,14 +167,14 @@ void FiltersPresenter::saveFaves()
   favesModelWriter.writeFaves();
 }
 
-void FiltersPresenter::addSelectedFilterAsNewFave(QList<QString> defaultValues, GmicQt::InputOutputState inOutState)
+void FiltersPresenter::addSelectedFilterAsNewFave(const QList<QString> & defaultValues, const QList<int> & visibilityStates, GmicQt::InputOutputState inOutState)
 {
   if (_currentFilter.hash.isEmpty() || (!_filtersModel.contains(_currentFilter.hash) && !_favesModel.contains(_currentFilter.hash))) {
     return;
   }
-
   FavesModel::Fave fave;
   fave.setDefaultValues(defaultValues);
+  fave.setDefaultVisibilities(visibilityStates);
 
   if (_filtersModel.contains(_currentFilter.hash)) {
     const FiltersModel::Filter & filter = _filtersModel.getFilterFromHash(_currentFilter.hash);
@@ -200,6 +199,7 @@ void FiltersPresenter::addSelectedFilterAsNewFave(QList<QString> defaultValues,
   FiltersVisibilityMap::setVisibility(fave.hash(), true);
   _favesModel.addFave(fave);
   ParametersCache::setValues(fave.hash(), defaultValues);
+  ParametersCache::setVisibilityStates(fave.hash(), visibilityStates);
   ParametersCache::setInputOutputState(fave.hash(), inOutState);
   _filtersView->addFave(fave.name(), fave.hash());
   _filtersView->sortFaves();
@@ -260,9 +260,7 @@ void FiltersPresenter::saveSettings(QSettings & settings)
 
 void FiltersPresenter::setInvalidFilter()
 {
-  _currentFilter.clear();
-  _currentFilter.command = "skip";
-  _currentFilter.previewCommand = "skip";
+  _currentFilter.setInvalid();
 }
 
 bool FiltersPresenter::isInvalidFilter() const
@@ -296,6 +294,11 @@ void FiltersPresenter::collapseAll()
   _filtersView->collapseAll();
 }
 
+const QString & FiltersPresenter::errorMessage() const
+{
+  return _errorMessage;
+}
+
 void FiltersPresenter::removeSelectedFave()
 {
   QString hash = _filtersView->selectedFilterHash();
@@ -307,11 +310,12 @@ void FiltersPresenter::editSelectedFaveName()
   _filtersView->editSelectedFaveName();
 }
 
-void FiltersPresenter::onFaveRenamed(QString hash, QString newName)
+void FiltersPresenter::onFaveRenamed(const QString & hash, const QString & name)
 {
   Q_ASSERT_X(_favesModel.contains(hash), "onFaveRenamed()", "Hash not found");
   FavesModel::Fave fave = _favesModel.getFaveFromHash(hash);
   _favesModel.removeFave(hash);
+  QString newName = name;
   if (newName.isEmpty()) {
     if (_filtersModel.contains(fave.originalHash())) {
       const FiltersModel::Filter & originalFilter = _filtersModel.getFilterFromHash(fave.originalHash());
@@ -328,9 +332,11 @@ void FiltersPresenter::onFaveRenamed(QString hash, QString newName)
 
   // Move parameters
   QList<QString> values = ParametersCache::getValues(hash);
+  QList<int> visibilityStates = ParametersCache::getVisibilityStates(hash);
   GmicQt::InputOutputState inOutState = ParametersCache::getInputOutputState(hash);
   ParametersCache::remove(hash);
   ParametersCache::setValues(fave.hash(), values);
+  ParametersCache::setVisibilityStates(fave.hash(), visibilityStates);
   ParametersCache::setInputOutputState(fave.hash(), inOutState);
 
   _favesModel.addFave(fave);
@@ -348,13 +354,13 @@ void FiltersPresenter::toggleSelectionMode(bool on)
   }
 }
 
-void FiltersPresenter::onFilterChanged(QString hash)
+void FiltersPresenter::onFilterChanged(const QString & hash)
 {
   setCurrentFilter(hash);
   emit filterSelectionChanged();
 }
 
-void FiltersPresenter::removeFave(QString hash)
+void FiltersPresenter::removeFave(const QString & hash)
 {
   if (hash.isEmpty() || !_favesModel.contains(hash)) {
     return;
@@ -366,8 +372,21 @@ void FiltersPresenter::removeFave(QString hash)
   onFilterChanged(_filtersView->selectedFilterHash());
 }
 
-void FiltersPresenter::setCurrentFilter(QString hash)
+bool FiltersPresenter::danglingFaveIsSelected() const
 {
+  if (!_filtersView->aFaveIsSelected()) {
+    return false;
+  }
+  QString hash = _filtersView->selectedFilterHash();
+  if (_favesModel.contains(hash)) {
+    return not _filtersModel.contains(_favesModel.getFaveFromHash(hash).originalHash());
+  }
+  return false;
+}
+
+void FiltersPresenter::setCurrentFilter(const QString & hash)
+{
+  _errorMessage.clear();
   if (hash.isEmpty()) {
     _currentFilter.clear();
   } else if (_favesModel.contains(hash)) {
@@ -377,6 +396,7 @@ void FiltersPresenter::setCurrentFilter(QString hash)
       const FiltersModel::Filter & filter = _filtersModel.getFilterFromHash(originalHash);
       _currentFilter.command = fave.command();
       _currentFilter.defaultParameterValues = fave.defaultValues();
+      _currentFilter.defaultVisibilityStates = fave.defaultVisibilityStates();
       _currentFilter.hash = hash;
       _currentFilter.isAFave = true;
       _currentFilter.name = fave.name();
@@ -385,11 +405,15 @@ void FiltersPresenter::setCurrentFilter(QString hash)
       _currentFilter.previewCommand = fave.previewCommand();
       _currentFilter.isAccurateIfZoomed = filter.isAccurateIfZoomed();
       _currentFilter.previewFactor = filter.previewFactor();
+    } else {
+      setInvalidFilter();
+      _errorMessage = tr("Cannot find this fave's original filter\n");
     }
   } else if (_filtersModel.contains(hash)) {
     const FiltersModel::Filter & filter = _filtersModel.getFilterFromHash(hash);
     _currentFilter.command = filter.command();
     _currentFilter.defaultParameterValues = ParametersCache::getValues(hash);
+    _currentFilter.defaultVisibilityStates = ParametersCache::getVisibilityStates(hash);
     _currentFilter.hash = hash;
     _currentFilter.isAFave = false;
     _currentFilter.name = filter.name();
